@@ -34,4 +34,13 @@ test_that("query values returns only unique", {
       query(webgeom(geom="sample:Counties" , attribute = "STATE_FIPS"), 'values'))
     )
   )
+})
+
+context("Create WFS post XML works")
+test_that("two states", {
+  wg <- readRDS("data/test_wfsgetfeature_wg.rds")
+  xml <- geoknife:::wfsFilterFeatureXML(wg)
+
+  fn <- "data/test_wfsgetfeature.xml"
+  expect_equal(xml,readChar(fn, file.info(fn)$size))
 })
\ No newline at end of file
